@@ -11,6 +11,7 @@
 '''
 
 import os
+import torch
 
 meta = {
     "voicefixer_fe": {
@@ -25,3 +26,5 @@ if (not os.path.exists(meta["voicefixer_fe"]['path'])):
     cmd = "wget https://zenodo.org/record/5469951/files/epoch%3D15_trimed_bn.ckpt?download=1 -O " + \
           meta["voicefixer_fe"]['path']
     os.system(cmd)
+    temp = torch.load(meta["voicefixer_fe"]['path'])
+    torch.save(temp['state_dict'], os.path.join(os.path.expanduser('~'), ".cache/voicefixer/analysis_module/checkpoints/vf.ckpt"))
